==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/GeographicProportionalSymbolSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMarkerSeriesBaseDescriptionMetadata } from "./GeographicMarkerSeriesBaseDescriptionMetadata";
/**
 * @hidden
 */
export let GeographicProportionalSymbolSeriesBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicProportionalSymbolSeriesBaseDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a == null) {
                GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicProportionalSymbolSeriesBaseDescriptionMetadata.c(GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a);
            }
            if (a.k(GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a)) {
                return;
            }
            a.ab(GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a);
        }
        static c(a) {
            GeographicMarkerSeriesBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            GeographicProportionalSymbolSeriesBaseDescriptionMetadata.b(a);
            a.ac("GeographicProportionalSymbolSeriesBase", GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a);
        }
    }
    GeographicProportionalSymbolSeriesBaseDescriptionMetadata.$t = markType(GeographicProportionalSymbolSeriesBaseDescriptionMetadata, 'GeographicProportionalSymbolSeriesBaseDescriptionMetadata');
    GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a = null;
    return GeographicProportionalSymbolSeriesBaseDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/GeographicProportionalSymbolSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMarkerSeriesBaseDescriptionMetadata } from "./GeographicMarkerSeriesBaseDescriptionMetadata";
/**
 * @hidden
 */
export let GeographicProportionalSymbolSeriesBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicProportionalSymbolSeriesBaseDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a == null) {
                GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicProportionalSymbolSeriesBaseDescriptionMetadata.c(GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a);
            }
            if (a.k(GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a)) {
                return;
            }
            a.ac(GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a);
        }
        static c(a) {
            GeographicMarkerSeriesBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            GeographicProportionalSymbolSeriesBaseDescriptionMetadata.b(a);
            a.ad("GeographicProportionalSymbolSeriesBase", GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a);
        }
    }
    GeographicProportionalSymbolSeriesBaseDescriptionMetadata.$t = markType(GeographicProportionalSymbolSeriesBaseDescriptionMetadata, 'GeographicProportionalSymbolSeriesBaseDescriptionMetadata');
    GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a = null;
    return GeographicProportionalSymbolSeriesBaseDescriptionMetadata;
})();
